Summary: Common Unix Printing System
Name: cups
Version: 1.4.4
Release: 1
License: GPLv2
Group: System Environment/Daemons
Source0: http://ftp.easysw.com/pub/cups/%{version}/%{name}-%{version}-source.tar.bz2
URL: http://www.cups.org/
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

BuildRequires: openssl-devel >= 0.9.8
BuildRequires: make
BuildRequires: libjpeg-devel
BuildRequires: libpaper-devel
BuildRequires: libpng-devel
BuildRequires: libtiff-devel
BuildRequires: zlib-devel

Requires: %{name}-libs = %{version}-%{release}
Requires: libpaper
Requires: openssl >= 0.9.8
Requires: zlib

%define cups_serverbin %{_libdir}/%{name}

%ifos aix5.1
Requires: AIX-rpm >= 5.1.0.0
Requires: AIX-rpm < 5.2.0.0
%endif
%ifos aix5.2
Requires: AIX-rpm >= 5.2.0.0
Requires: AIX-rpm < 5.3.0.0
%endif
%ifos aix5.3
Requires: AIX-rpm >= 5.3.0.0
Requires: AIX-rpm < 5.4.0.0
%endif
%ifos aix6.1
Requires: AIX-rpm >= 6.1.0.0
Requires: AIX-rpm < 6.2.0.0
%endif
%ifos aix7.1
Requires: AIX-rpm >= 7.1.0.0
%endif

%description
The Common UNIX Printing System provides a portable printing layer for 
UNIX operating systems. It has been developed by Easy Software Products 
to promote a standard printing solution for all UNIX vendors and users. 
CUPS provides the System V and Berkeley command-line interfaces. 


%package devel
Summary: Common Unix Printing System - development environment
Group: Development/Libraries
License: LGPLv2
Requires: %{name}-libs = %{version}-%{release}
Requires: zlib-devel

%description devel
The Common UNIX Printing System provides a portable printing layer for 
UNIX operating systems. This is the development package for creating
additional printer drivers, and other CUPS services.


%package libs
Summary: Common Unix Printing System - libraries
Group: System Environment/Libraries
License: LGPLv2

Requires: openssl >= 0.9.8
Requires: libjpeg
Requires: libpng
Requires: libtiff
Requires: zlib

Requires: %{name}-libs = %{version}-%{release}
%description libs
The Common UNIX Printing System provides a portable printing layer for 
UNIX operating systems. It has been developed by Easy Software Products 
to promote a standard printing solution for all UNIX vendors and users. 
CUPS provides the System V and Berkeley command-line interfaces. 
The cups-libs package provides libraries used by applications to use CUPS
natively, without needing the lp/lpr commands.


%package lpd
Summary: Common Unix Printing System - lpd emulation
Group: System Environment/Daemons
Requires: %{name} = %{version}-%{release}
Requires: %{name}-libs = %{version}-%{release}

%description lpd
The Common UNIX Printing System provides a portable printing layer for 
UNIX operating systems. This is the package that provices standard 
lpd emulation.


%prep
%setup -q

# Fix locale code for Norwegian (bug #520379).
mv locale/cups_no.po locale/cups_nb.po


%build
export CC="cc -qcpluscmt"
export LDFLAGS="-L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"

./configure \
    --prefix=%{_prefix} \
    --mandir=%{_mandir} \
    --sysconfdir=/etc \
    --localstatedir=/var \
    --enable-shared --disable-static \
    --enable-libpaper \
    --enable-32bit \
    --enable-image \
    --enable-jpeg \
    --enable-png \
    --enable-tiff \
    --enable-openssl \
    --enable-bannertops \
    --enable-texttops \
    --with-openssl-libs=/opt/freeware/lib \
    --with-openssl-includes=/opt/freeware/include \
    --with-perl=/opt/freeware/bin/perl \
    --without-php \
    --without-python

make %{?_smp_mflags}


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}
make install DSTROOT=${RPM_BUILD_ROOT}

/usr/bin/strip ${RPM_BUILD_ROOT}%{_bindir}/* || :
/usr/bin/strip ${RPM_BUILD_ROOT}%{_sbindir}/* || :

/usr/bin/rm -rf ${RPM_BUILD_ROOT}/etc/rc[05].d

mkdir -p ${RPM_BUILD_ROOT}%{_datadir}/locale
/usr/bin/mv -f ${RPM_BUILD_ROOT}%{_libdir}/nls/msg/* ${RPM_BUILD_ROOT}%{_datadir}/locale/

# Handle https:// device URIs (bug #478677, STR #3122).
ln -s ipp ${RPM_BUILD_ROOT}%{cups_serverbin}/backend/https

(
  cd ${RPM_BUILD_ROOT}
  for dir in bin sbin include lib
  do
    mkdir -p usr/linux/${dir}
    cd usr/linux/${dir}
    ln -sf ../../..%{_prefix}/${dir}/* .
    cd -
  done
)


%post
# Remove old-style certs directory; new-style is /var/run
# (see bug #194581 for why this is necessary).
/usr/bin/rm -rf /etc/%{name}/certs
/usr/bin/rm -f /var/cache/%{name}/*.ipp /var/cache/%{name}/*.cache
exit 0


%preun
if [ "$1" = "0" ]; then
    /etc/rc.d/init.d/cups stop > /dev/null 2>&1
fi
exit 0


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,system)
%doc LICENSE.txt README.txt CREDITS.txt CHANGES.txt

%{_bindir}/cancel*
%{_bindir}/cupstestdsc
%{_bindir}/cupstestppd
%{_bindir}/lp*
%{_bindir}/ppd*

%{_sbindir}/*

/etc/rc.d/init.d/%{name}
/etc/rc.d/rc2.d/*%{name}
/etc/rc.d/rc3.d/*%{name}

%dir %attr(0755,root,lp) /etc/%{name}
%verify(not md5 size mtime) %config(noreplace) %attr(0640,root,lp) /etc/%{name}/cupsd.conf
%attr(0640,root,lp) /etc/%{name}/cupsd.conf.default
/etc/%{name}/interfaces
%dir %attr(0755,root,lp) /etc/%{name}/ppd
%verify(not md5 size mtime) %config(noreplace) %attr(0644,root,lp) /etc/%{name}/snmp.conf
%dir %attr(0700,root,lp) /etc/%{name}/ssl

%dir %attr(0755,root,lp) /var/run/%{name}
%dir %attr(0511,lp,system) /var/run/%{name}/certs

%dir %attr(0775,root,lp) /var/cache/%{name}
%dir %attr(0775,root,lp) /var/cache/%{name}/rss

%dir %attr(0710,root,lp) /var/spool/%{name}
%dir %attr(1770,root,lp) /var/spool/%{name}/tmp
%dir %attr(0755,lp,system) /var/log/%{name}

%dir %{cups_serverbin}
%{cups_serverbin}/backend
%{cups_serverbin}/cgi-bin
%dir %{cups_serverbin}/daemon
%{cups_serverbin}/daemon/cups-polld
%{cups_serverbin}/daemon/cups-deviced
%{cups_serverbin}/daemon/cups-driverd
%{cups_serverbin}/notifier
%{cups_serverbin}/filter
%{cups_serverbin}/monitor
%{cups_serverbin}/driver

%{_mandir}/man?/*

%dir %{_datadir}/doc/%{name}
%dir %{_datadir}/doc/%{name}/de
%dir %{_datadir}/doc/%{name}/es
%dir %{_datadir}/doc/%{name}/eu
%dir %{_datadir}/doc/%{name}/id
%dir %{_datadir}/doc/%{name}/it
%dir %{_datadir}/doc/%{name}/ja
%dir %{_datadir}/doc/%{name}/pl
%dir %{_datadir}/doc/%{name}/ru
%config(noreplace) %{_datadir}/doc/%{name}/*.css
%config(noreplace) %doc %{_datadir}/doc/%{name}/de/index.html
%config(noreplace) %doc %{_datadir}/doc/%{name}/es/index.html
%config(noreplace) %doc %{_datadir}/doc/%{name}/eu/index.html
%config(noreplace) %doc %{_datadir}/doc/%{name}/help
%config(noreplace) %doc %{_datadir}/doc/%{name}/id/index.html
%config(noreplace) %{_datadir}/doc/%{name}/images
%config(noreplace) %doc %{_datadir}/doc/%{name}/index.html
%config(noreplace) %doc %{_datadir}/doc/%{name}/it/index.html
%config(noreplace) %doc %{_datadir}/doc/%{name}/ja/index.html
%config(noreplace) %doc %{_datadir}/doc/%{name}/pl/index.html
%config(noreplace) %doc %{_datadir}/doc/%{name}/robots.txt
%config(noreplace) %doc %{_datadir}/doc/%{name}/ru/index.html

%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/banners
%config(noreplace) %{_datadir}/%{name}/banners/*
%{_datadir}/%{name}/charmaps
%{_datadir}/%{name}/charsets
%{_datadir}/%{name}/data
%{_datadir}/%{name}/fonts
%{_datadir}/%{name}/model

%dir %{_datadir}/%{name}/templates
%config(noreplace) %{_datadir}/%{name}/templates/*.tmpl
%dir %{_datadir}/%{name}/templates/de
%config(noreplace) %{_datadir}/%{name}/templates/de/*.tmpl
%dir %{_datadir}/%{name}/templates/es
%config(noreplace) %{_datadir}/%{name}/templates/es/*.tmpl
%dir %{_datadir}/%{name}/templates/eu
%config(noreplace) %{_datadir}/%{name}/templates/eu/*.tmpl
%dir %{_datadir}/%{name}/templates/id
%config(noreplace) %{_datadir}/%{name}/templates/id/*.tmpl
%dir %{_datadir}/%{name}/templates/it
%config(noreplace) %{_datadir}/%{name}/templates/it/*.tmpl
%dir %{_datadir}/%{name}/templates/ja
%config(noreplace) %{_datadir}/%{name}/templates/ja/*.tmpl
%dir %{_datadir}/%{name}/templates/pl
%config(noreplace) %{_datadir}/%{name}/templates/pl/*.tmpl
%dir %{_datadir}/%{name}/templates/ru
%config(noreplace) %{_datadir}/%{name}/templates/ru/*.tmpl

%{_datadir}/locale/*/*.po

%{_datadir}/%{name}/drv
%{_datadir}/%{name}/examples
%dir %{_datadir}/%{name}/mime
%config(noreplace) %{_datadir}/%{name}/mime/mime.types
%config(noreplace) %{_datadir}/%{name}/mime/mime.convs
%dir %{_datadir}/%{name}/ppdc
%{_datadir}/%{name}/ppdc/*.defs
%{_datadir}/%{name}/ppdc/*.h


/usr/linux/bin/cancel*
/usr/linux/bin/cupstestdsc
/usr/linux/bin/cupstestppd
/usr/linux/bin/lp*
/usr/linux/bin/ppd*
/usr/linux/sbin/*


%files libs
%defattr(-,root,system)
%{_libdir}/*.a
/usr/linux/lib/*.a


%files devel
%defattr(-,root,system)
%{_bindir}/cups-config
%{_includedir}/%{name}
/usr/linux/bin/cups-config
/usr/linux/include/%{name}


%files lpd
%defattr(-,root,system)
%dir %{cups_serverbin}
%dir %{cups_serverbin}/daemon
%{cups_serverbin}/daemon/cups-lpd


%changelog
* Tue Aug 03 2010 Michael Perzl <michael@perzl.org> - 1.4.4-1
- first version for AIX V5.1 and higher
